pub struct TranscodingError { /* private fields */ }Expand description
A malformed byte sequence encountered while strictly transcoding to UTF-8.
Implementations
Sourceimpl TranscodingError
impl TranscodingError
Sourcepub fn malformed_sequence_length(&self) -> u8
pub fn malformed_sequence_length(&self) -> u8
The number of bytes in the malformed sequence.
Sourcepub fn bytes_after_malformed(&self) -> u8
pub fn bytes_after_malformed(&self) -> u8
The number of bytes consumed after the malformed sequence.